@@ -1317,6 +1317,8 @@ public abstract class AbstractIoBuffer extends IoBuffer {
         } else {
             buf.append("HeapBuffer");
         }
+        buf.append("@");
+        buf.append(Integer.toHexString(super.hashCode()));
         buf.append("[pos=");
         buf.append(position());
         buf.append(" lim=");
@@ -2720,7 +2722,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
 
     /**
      * This method forwards the call to {@link #expand(int)} only when
-     * <tt>autoExpand</tt> property is <tt>true</tt>.
+     * <code>autoExpand</code> property is <code>true</code>.
      */
     private IoBuffer autoExpand(int expectedRemaining) {
         if (isAutoExpand()) {
@@ -2731,7 +2733,7 @@ public abstract class AbstractIoBuffer extends IoBuffer {
 
     /**
      * This method forwards the call to {@link #expand(int)} only when
-     * <tt>autoExpand</tt> property is <tt>true</tt>.
+     * <code>autoExpand</code> property is <code>true</code>.
      */
     private IoBuffer autoExpand(int pos, int expectedRemaining) {
         if (isAutoExpand()) {
