@@ -104,7 +104,7 @@ class IoBufferHexDumper {
         final StringBuilder sb = new StringBuilder();
 
         sb.append("Source ");
-        sb.append(buf);
+        sb.append("0x").append(Integer.toHexString(buf.hashCode()));
         sb.append(" showing index ");
         sb.append(offset);
         sb.append(" through ");
@@ -163,13 +163,13 @@ class IoBufferHexDumper {
      *
      * @param pos  index position to begin reading
      *
-     * @param len  number of bytes to read; this can be less than the <tt>line</tt>
+     * @param len  number of bytes to read; this can be less than the <code>line</code>
      *             width
      *
      * @param col  number of bytes in a column
      *
-     * @param line line width in bytes which pads the output if <tt>len</tt> is less
-     *             than <tt>line</tt>
+     * @param line line width in bytes which pads the output if <code>len</code> is less
+     *             than <code>line</code>
      *
      * @return string hex dump
      */
@@ -231,4 +231,4 @@ class IoBufferHexDumper {
         final char[] array = { hexDigit[(b >> 4) & 0x0f], hexDigit[b & 0x0f] };
         return new String(array);
     }
-}
\ No newline at end of file
+}
