@@ -19,9 +19,12 @@
  */
 package org.apache.mina.filter.codec;
 
-import java.util.LinkedList;
+import java.util.ArrayDeque;
 import java.util.Queue;
 
+import org.apache.mina.core.filterchain.IoFilter.NextFilter;
+import org.apache.mina.core.session.IoSession;
+
 /**
  * A {@link ProtocolDecoderOutput} based on queue.
  *
@@ -29,7 +32,7 @@ import java.util.Queue;
  */
 public abstract class AbstractProtocolDecoderOutput implements ProtocolDecoderOutput {
     /** The queue where decoded messages are stored */
-    private final Queue<Object> messageQueue = new LinkedList<>();
+    protected final Queue<Object> messageQueue = new ArrayDeque<>();
 
     /**
      * Creates a new instance of a AbstractProtocolDecoderOutput
@@ -38,13 +41,6 @@ public abstract class AbstractProtocolDecoderOutput implements ProtocolDecoderOu
         // Do nothing
     }
 
-    /**
-     * @return The decoder's message queue
-     */
-    public Queue<Object> getMessageQueue() {
-        return messageQueue;
-    }
-
     /**
      * {@inheritDoc}
      */
@@ -56,4 +52,16 @@ public abstract class AbstractProtocolDecoderOutput implements ProtocolDecoderOu
 
         messageQueue.add(message);
     }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public void flush(NextFilter nextFilter, IoSession session) {
+        Object message = null;
+
+        while ((message = messageQueue.poll()) != null) {
+            nextFilter.messageReceived(session, message);
+        }
+    }
 }
