@@ -27,13 +27,10 @@ import org.apache.mina.core.file.FileRegion;
 import org.apache.mina.core.filterchain.IoFilter;
 import org.apache.mina.core.filterchain.IoFilterAdapter;
 import org.apache.mina.core.filterchain.IoFilterChain;
-import org.apache.mina.core.future.DefaultWriteFuture;
 import org.apache.mina.core.future.WriteFuture;
-import org.apache.mina.core.session.AbstractIoSession;
 import org.apache.mina.core.session.AttributeKey;
 import org.apache.mina.core.session.IoSession;
 import org.apache.mina.core.write.DefaultWriteRequest;
-import org.apache.mina.core.write.NothingWrittenException;
 import org.apache.mina.core.write.WriteRequest;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -58,16 +55,16 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
 
     private static final AttributeKey DECODER = new AttributeKey(ProtocolCodecFilter.class, "decoder");
 
-    private static final AttributeKey DECODER_OUT = new AttributeKey(ProtocolCodecFilter.class, "decoderOut");
+    private static final ProtocolDecoderOutputLocal DECODER_OUTPUT = new ProtocolDecoderOutputLocal();
 
-    private static final AttributeKey ENCODER_OUT = new AttributeKey(ProtocolCodecFilter.class, "encoderOut");
+    private static final ProtocolEncoderOutputLocal ENCODER_OUTPUT = new ProtocolEncoderOutputLocal();
 
     /** The factory responsible for creating the encoder and decoder */
     private final ProtocolCodecFactory factory;
 
     /**
-     * Creates a new instance of ProtocolCodecFilter, associating a factory
-     * for the creation of the encoder and decoder.
+     * Creates a new instance of ProtocolCodecFilter, associating a factory for the
+     * creation of the encoder and decoder.
      *
      * @param factory The associated factory
      */
@@ -80,9 +77,9 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
     }
 
     /**
-     * Creates a new instance of ProtocolCodecFilter, without any factory.
-     * The encoder/decoder factory will be created as an inner class, using
-     * the two parameters (encoder and decoder).
+     * Creates a new instance of ProtocolCodecFilter, without any factory. The
+     * encoder/decoder factory will be created as an inner class, using the two
+     * parameters (encoder and decoder).
      * 
      * @param encoder The class responsible for encoding the message
      * @param decoder The class responsible for decoding the message
@@ -116,10 +113,10 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
     }
 
     /**
-     * Creates a new instance of ProtocolCodecFilter, without any factory.
-     * The encoder/decoder factory will be created as an inner class, using
-     * the two parameters (encoder and decoder), which are class names. Instances
-     * for those classes will be created in this constructor.
+     * Creates a new instance of ProtocolCodecFilter, without any factory. The
+     * encoder/decoder factory will be created as an inner class, using the two
+     * parameters (encoder and decoder), which are class names. Instances for those
+     * classes will be created in this constructor.
      * 
      * @param encoderClass The class responsible for encoding the message
      * @param decoderClass The class responsible for decoding the message
@@ -217,18 +214,15 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
 
     /**
      * Process the incoming message, calling the session decoder. As the incoming
-     * buffer might contains more than one messages, we have to loop until the decoder
-     * throws an exception.
+     * buffer might contains more than one messages, we have to loop until the
+     * decoder throws an exception.
      * 
-     *  while ( buffer not empty )
-     *    try
-     *      decode ( buffer )
-     *    catch
-     *      break;
+     * while ( buffer not empty ) try decode ( buffer ) catch break;
      * 
      */
     @Override
-    public void messageReceived(NextFilter nextFilter, IoSession session, Object message) throws Exception {
+    public void messageReceived(final NextFilter nextFilter, final IoSession session, final Object message)
+            throws Exception {
         if (LOGGER.isDebugEnabled()) {
             LOGGER.debug("Processing a MESSAGE_RECEIVED for session {}", session.getId());
         }
@@ -238,9 +232,9 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
             return;
         }
 
-        IoBuffer in = (IoBuffer) message;
-        ProtocolDecoder decoder = factory.getDecoder(session);
-        ProtocolDecoderOutput decoderOut = getDecoderOut(session, nextFilter);
+        final IoBuffer in = (IoBuffer) message;
+        final ProtocolDecoder decoder = factory.getDecoder(session);
+        final ProtocolDecoderOutputImpl decoderOut = DECODER_OUTPUT.get();
 
         // Loop until we don't have anymore byte in the buffer,
         // or until the decoder throws an unrecoverable exception or
@@ -249,10 +243,8 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
         while (in.hasRemaining()) {
             int oldPos = in.position();
             try {
-                synchronized (session) {
-                    // Call the decoder with the read bytes
-                    decoder.decode(session, in, decoderOut);
-                }
+                // Call the decoder with the read bytes
+                decoder.decode(session, in, decoderOut);
                 // Finish decoding if no exception was thrown.
                 decoderOut.flush(nextFilter, session);
             } catch (Exception e) {
@@ -299,8 +291,9 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
      * {@inheritDoc}
      */
     @Override
-    public void filterWrite(NextFilter nextFilter, IoSession session, WriteRequest writeRequest) throws Exception {
-        Object message = writeRequest.getMessage();
+    public void filterWrite(final NextFilter nextFilter, final IoSession session, final WriteRequest writeRequest)
+            throws Exception {
+        final Object message = writeRequest.getMessage();
 
         // Bypass the encoding if the message is contained in a IoBuffer,
         // as it has already been encoded before
@@ -310,9 +303,8 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
         }
 
         // Get the encoder in the session
-        ProtocolEncoder encoder = factory.getEncoder(session);
-
-        ProtocolEncoderOutput encoderOut = getEncoderOut(session, nextFilter, writeRequest);
+        final ProtocolEncoder encoder = factory.getEncoder(session);
+        final ProtocolEncoderOutputImpl encoderOut = ENCODER_OUTPUT.get();
 
         if (encoder == null) {
             throw new ProtocolEncoderException("The encoder is null for the session " + session);
@@ -322,20 +314,20 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
             // Now we can try to encode the response
             encoder.encode(session, message, encoderOut);
 
-            // Send it directly
-            Queue<Object> bufferQueue = ((AbstractProtocolEncoderOutput) encoderOut).getMessageQueue();
+            final Queue<Object> queue = encoderOut.messageQueue;
 
-            // Write all the encoded messages now
-            while (!bufferQueue.isEmpty()) {
-                Object encodedMessage = bufferQueue.poll();
+            if (queue.isEmpty()) {
+                // Write empty message to ensure that messageSent is fired later
+                writeRequest.setMessage(EMPTY_BUFFER);
+                nextFilter.filterWrite(session, writeRequest);
+            } else {
+                // Write all the encoded messages now
+                Object encodedMessage = null;
 
-                if (encodedMessage == null) {
-                    break;
-                }
-
-                // Flush only when the buffer has remaining.
-                if (!(encodedMessage instanceof IoBuffer) || ((IoBuffer) encodedMessage).hasRemaining()) {
-                    if (bufferQueue.isEmpty()) {
+                while ((encodedMessage = queue.poll()) != null) {
+                    if (queue.isEmpty()) {
+                        // Write last message using original WriteRequest to ensure that any Future and
+                        // dependency on messageSent event is emitted correctly
                         writeRequest.setMessage(encodedMessage);
                         nextFilter.filterWrite(session, writeRequest);
                     } else {
@@ -345,17 +337,11 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
                     }
                 }
             }
-        } catch (Exception e) {
-            ProtocolEncoderException pee;
-
+        } catch (final ProtocolEncoderException e) {
+            throw e;
+        } catch (final Exception e) {
             // Generate the correct exception
-            if (e instanceof ProtocolEncoderException) {
-                pee = (ProtocolEncoderException) e;
-            } else {
-                pee = new ProtocolEncoderException(e);
-            }
-
-            throw pee;
+            throw new ProtocolEncoderException(e);
         }
     }
 
@@ -366,7 +352,7 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
     public void sessionClosed(NextFilter nextFilter, IoSession session) throws Exception {
         // Call finishDecode() first when a connection is closed.
         ProtocolDecoder decoder = factory.getDecoder(session);
-        ProtocolDecoderOutput decoderOut = getDecoderOut(session, nextFilter);
+        ProtocolDecoderOutput decoderOut = DECODER_OUTPUT.get();
 
         try {
             decoder.finishDecode(session, decoderOut);
@@ -406,86 +392,28 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
         public ProtocolDecoderOutputImpl() {
             // Do nothing
         }
-
-        /**
-         * {@inheritDoc}
-         */
-        @Override
-        public void flush(NextFilter nextFilter, IoSession session) {
-            Queue<Object> messageQueue = getMessageQueue();
-
-            while (!messageQueue.isEmpty()) {
-                nextFilter.messageReceived(session, messageQueue.poll());
-            }
-        }
     }
 
     private static class ProtocolEncoderOutputImpl extends AbstractProtocolEncoderOutput {
-        private final IoSession session;
-
-        private final NextFilter nextFilter;
-
-        /** The WriteRequest destination */
-        private final SocketAddress destination;
-
-        public ProtocolEncoderOutputImpl(IoSession session, NextFilter nextFilter, WriteRequest writeRequest) {
-            this.session = session;
-            this.nextFilter = nextFilter;
-
-            // Only store the destination, not the full WriteRequest.
-            destination = writeRequest.getDestination();
-        }
-
-        /**
-         * {@inheritDoc}
-         */
-        @Override
-        public WriteFuture flush() {
-            Queue<Object> bufferQueue = getMessageQueue();
-            WriteFuture future = null;
-
-            while (!bufferQueue.isEmpty()) {
-                Object encodedMessage = bufferQueue.poll();
-
-                if (encodedMessage == null) {
-                    break;
-                }
-
-                // Flush only when the buffer has remaining.
-                if (!(encodedMessage instanceof IoBuffer) || ((IoBuffer) encodedMessage).hasRemaining()) {
-                    future = new DefaultWriteFuture(session);
-                    nextFilter.filterWrite(session, new EncodedWriteRequest(encodedMessage, future, destination));
-                }
-            }
-
-            if (future == null) {
-                // Creates an empty writeRequest containing the destination
-                future = DefaultWriteFuture.newNotWrittenFuture(session, new NothingWrittenException(AbstractIoSession.MESSAGE_SENT_REQUEST));
-            }
-
-            return future;
+        public ProtocolEncoderOutputImpl() {
+            // Do nothing
         }
     }
 
-    //----------- Helper methods ---------------------------------------------
+    // ----------- Helper methods ---------------------------------------------
     /**
-     * Dispose the encoder, decoder, and the callback for the decoded
-     * messages.
+     * Dispose the encoder, decoder, and the callback for the decoded messages.
      */
     private void disposeCodec(IoSession session) {
         // We just remove the two instances of encoder/decoder to release resources
         // from the session
         disposeEncoder(session);
         disposeDecoder(session);
-
-        // We also remove the callback
-        disposeDecoderOut(session);
     }
 
     /**
-     * Dispose the encoder, removing its instance from the
-     * session's attributes, and calling the associated
-     * dispose method.
+     * Dispose the encoder, removing its instance from the session's attributes, and
+     * calling the associated dispose method.
      */
     private void disposeEncoder(IoSession session) {
         ProtocolEncoder encoder = (ProtocolEncoder) session.removeAttribute(ENCODER);
@@ -501,9 +429,8 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
     }
 
     /**
-     * Dispose the decoder, removing its instance from the
-     * session's attributes, and calling the associated
-     * dispose method.
+     * Dispose the decoder, removing its instance from the session's attributes, and
+     * calling the associated dispose method.
      */
     private void disposeDecoder(IoSession session) {
         ProtocolDecoder decoder = (ProtocolDecoder) session.removeAttribute(DECODER);
@@ -518,38 +445,17 @@ public class ProtocolCodecFilter extends IoFilterAdapter {
         }
     }
 
-    /**
-     * Return a reference to the decoder callback. If it's not already created
-     * and stored into the session, we create a new instance.
-     */
-    private ProtocolDecoderOutput getDecoderOut(IoSession session, NextFilter nextFilter) {
-        ProtocolDecoderOutput out = (ProtocolDecoderOutput) session.getAttribute(DECODER_OUT);
-
-        if (out == null) {
-            // Create a new instance, and stores it into the session
-            out = new ProtocolDecoderOutputImpl();
-            session.setAttribute(DECODER_OUT, out);
+    static private class ProtocolDecoderOutputLocal extends ThreadLocal<ProtocolDecoderOutputImpl> {
+        @Override
+        protected ProtocolDecoderOutputImpl initialValue() {
+            return new ProtocolDecoderOutputImpl();
         }
-
-        return out;
     }
 
-    private ProtocolEncoderOutput getEncoderOut(IoSession session, NextFilter nextFilter, WriteRequest writeRequest) {
-        ProtocolEncoderOutput out = (ProtocolEncoderOutput) session.getAttribute(ENCODER_OUT);
-
-        if (out == null) {
-            // Create a new instance, and stores it into the session
-            out = new ProtocolEncoderOutputImpl(session, nextFilter, writeRequest);
-            session.setAttribute(ENCODER_OUT, out);
+    static private class ProtocolEncoderOutputLocal extends ThreadLocal<ProtocolEncoderOutputImpl> {
+        @Override
+        protected ProtocolEncoderOutputImpl initialValue() {
+            return new ProtocolEncoderOutputImpl();
         }
-
-        return out;
-    }
-
-    /**
-     * Remove the decoder callback from the session's attributes.
-     */
-    private void disposeDecoderOut(IoSession session) {
-        session.removeAttribute(DECODER_OUT);
     }
 }
