@@ -255,12 +255,13 @@ public class OrderedThreadPoolExecutor extends ThreadPoolExecutor {
             Worker worker = new Worker();
             Thread thread = getThreadFactory().newThread(worker);
 
+            workers.add(worker);
+
             // As we have added a new thread, it's considered as idle.
             idleWorkers.incrementAndGet();
 
             // Now, we can start it.
             thread.start();
-            workers.add(worker);
 
             if (workers.size() > largestPoolSize) {
                 largestPoolSize = workers.size();
@@ -681,8 +682,6 @@ public class OrderedThreadPoolExecutor extends ThreadPoolExecutor {
                     if (session == null) {
                         synchronized (workers) {
                             if (workers.size() > getCorePoolSize()) {
-                                // Remove now to prevent duplicate exit.
-                                workers.remove(this);
                                 break;
                             }
                         }
@@ -692,13 +691,11 @@ public class OrderedThreadPoolExecutor extends ThreadPoolExecutor {
                         break;
                     }
 
-                    try {
-                        if (session != null) {
-                            runTasks(getSessionTasksQueue(session));
-                        }
-                    } finally {
-                        idleWorkers.incrementAndGet();
+                    if (session != null) {
+                        runTasks(getSessionTasksQueue(session));
                     }
+
+                    idleWorkers.incrementAndGet();
                 }
             } finally {
                 synchronized (workers) {
