@@ -25,10 +25,11 @@ import org.apache.mina.core.session.IdleStatus;
 import org.apache.mina.core.session.IoEventType;
 import org.apache.mina.core.session.IoSession;
 import org.apache.mina.core.write.WriteRequest;
+import org.apache.mina.filter.FilterEvent;
 
 /**
  * Extend this class when you want to create a filter that
- * wraps the same logic around all 9 IoEvents
+ * wraps the same logic around all 11 IoEvents
  * 
  * @author <a href="http://mina.apache.org">Apache MINA Project</a>
  */
@@ -39,32 +40,8 @@ public abstract class CommonEventFilter extends IoFilterAdapter {
      * {@inheritDoc}
      */
     @Override
-    public final void sessionCreated(NextFilter nextFilter, IoSession session) throws Exception {
-        filter(new IoFilterEvent(nextFilter, IoEventType.SESSION_CREATED, session, null));
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    @Override
-    public final void sessionOpened(NextFilter nextFilter, IoSession session) throws Exception {
-        filter(new IoFilterEvent(nextFilter, IoEventType.SESSION_OPENED, session, null));
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    @Override
-    public final void sessionClosed(NextFilter nextFilter, IoSession session) throws Exception {
-        filter(new IoFilterEvent(nextFilter, IoEventType.SESSION_CLOSED, session, null));
-    }
-
-    /**
-     * {@inheritDoc}
-     */
-    @Override
-    public final void sessionIdle(NextFilter nextFilter, IoSession session, IdleStatus status) throws Exception {
-        filter(new IoFilterEvent(nextFilter, IoEventType.SESSION_IDLE, session, status));
+    public void event(NextFilter nextFilter, IoSession session, FilterEvent event) throws Exception {
+        filter(new IoFilterEvent(nextFilter, IoEventType.EVENT, session, event));
     }
 
     /**
@@ -75,6 +52,30 @@ public abstract class CommonEventFilter extends IoFilterAdapter {
         filter(new IoFilterEvent(nextFilter, IoEventType.EXCEPTION_CAUGHT, session, cause));
     }
 
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public final void filterClose(NextFilter nextFilter, IoSession session) throws Exception {
+        filter(new IoFilterEvent(nextFilter, IoEventType.CLOSE, session, null));
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public final void filterWrite(NextFilter nextFilter, IoSession session, WriteRequest writeRequest) throws Exception {
+        filter(new IoFilterEvent(nextFilter, IoEventType.WRITE, session, writeRequest));
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public void inputClosed(NextFilter nextFilter, IoSession session) throws Exception {
+        filter(new IoFilterEvent(nextFilter, IoEventType.INPUT_CLOSED, session, null));
+    }
+
     /**
      * {@inheritDoc}
      */
@@ -95,15 +96,31 @@ public abstract class CommonEventFilter extends IoFilterAdapter {
      * {@inheritDoc}
      */
     @Override
-    public final void filterWrite(NextFilter nextFilter, IoSession session, WriteRequest writeRequest) throws Exception {
-        filter(new IoFilterEvent(nextFilter, IoEventType.WRITE, session, writeRequest));
+    public final void sessionClosed(NextFilter nextFilter, IoSession session) throws Exception {
+        filter(new IoFilterEvent(nextFilter, IoEventType.SESSION_CLOSED, session, null));
     }
 
     /**
      * {@inheritDoc}
      */
     @Override
-    public final void filterClose(NextFilter nextFilter, IoSession session) throws Exception {
-        filter(new IoFilterEvent(nextFilter, IoEventType.CLOSE, session, null));
+    public final void sessionCreated(NextFilter nextFilter, IoSession session) throws Exception {
+        filter(new IoFilterEvent(nextFilter, IoEventType.SESSION_CREATED, session, null));
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public final void sessionIdle(NextFilter nextFilter, IoSession session, IdleStatus status) throws Exception {
+        filter(new IoFilterEvent(nextFilter, IoEventType.SESSION_IDLE, session, status));
+    }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public final void sessionOpened(NextFilter nextFilter, IoSession session) throws Exception {
+        filter(new IoFilterEvent(nextFilter, IoEventType.SESSION_OPENED, session, null));
     }
 }
