@@ -37,7 +37,7 @@ import org.slf4j.LoggerFactory;
  * @since MINA 2.0.0-M3
  */
 public class HttpProxyRequest extends ProxyRequest {
-    private static final Logger logger = LoggerFactory.getLogger(HttpProxyRequest.class);
+    private static final Logger LOGGER = LoggerFactory.getLogger(HttpProxyRequest.class);
 
     /**
      * The HTTP verb.
@@ -102,7 +102,7 @@ public class HttpProxyRequest extends ProxyRequest {
     public HttpProxyRequest(final InetSocketAddress endpointAddress, final String httpVersion,
             final Map<String, List<String>> headers) {
         this.httpVerb = HttpProxyConstants.CONNECT;
-        if (!endpointAddress.isUnresolved()) {
+        if (endpointAddress.isUnresolved()) {
             this.httpURI = endpointAddress.getHostName() + ":" + endpointAddress.getPort();
         } else {
             this.httpURI = endpointAddress.getAddress().getHostAddress() + ":" + endpointAddress.getPort();
@@ -199,7 +199,9 @@ public class HttpProxyRequest extends ProxyRequest {
                 try {
                     host = (new URL(httpURI)).getHost();
                 } catch (MalformedURLException e) {
-                    logger.debug("Malformed URL", e);
+                    if (LOGGER.isDebugEnabled()) {
+                        LOGGER.debug("Malformed URL", e);
+                    }
                 }
             }
         }
@@ -288,7 +290,7 @@ public class HttpProxyRequest extends ProxyRequest {
                 }
             }
 
-            if (!hostHeaderFound && getHttpVersion() == HttpProxyConstants.HTTP_1_1) {
+            if (!hostHeaderFound && HttpProxyConstants.HTTP_1_1.equals(getHttpVersion())) {
                 sb.append("Host: ").append(getHost()).append(HttpProxyConstants.CRLF);
             }
         }
@@ -297,4 +299,4 @@ public class HttpProxyRequest extends ProxyRequest {
 
         return sb.toString();
     }
-}
\ No newline at end of file
+}
