@@ -27,13 +27,13 @@ import org.apache.mina.core.filterchain.IoFilter;
 import org.apache.mina.core.future.ConnectFuture;
 import org.apache.mina.core.service.IoHandler;
 import org.apache.mina.core.session.IoSession;
-import org.apache.mina.example.echoserver.ssl.BogusSslContextFactory;
-import org.apache.mina.filter.ssl.SslFilter;
+import org.apache.mina.example.echoserver.ssl.BogusSSLContextFactory;
 import org.apache.mina.filter.codec.ProtocolCodecFilter;
 import org.apache.mina.filter.codec.textline.TextLineCodecFactory;
 import org.apache.mina.filter.compression.CompressionFilter;
 import org.apache.mina.filter.logging.LoggingFilter;
 import org.apache.mina.filter.logging.MdcInjectionFilter;
+import org.apache.mina.filter.ssl.SslFilter;
 import org.apache.mina.transport.socket.nio.NioSocketConnector;
 
 /**
@@ -77,10 +77,9 @@ public class ChatClientSupport {
             connector.getFilterChain().addLast("logger", LOGGING_FILTER);
 
             if (useSsl) {
-                SSLContext sslContext = BogusSslContextFactory
+                SSLContext sslContext = BogusSSLContextFactory
                         .getInstance(false);
                 SslFilter sslFilter = new SslFilter(sslContext);
-                sslFilter.setUseClientMode(true);
                 connector.getFilterChain().addFirst("sslFilter", sslFilter);
             }
 
