@@ -68,10 +68,9 @@ public class TcpSslClient extends IoHandlerAdapter {
         connector = new NioSocketConnector();
 
         // Inject teh SSL filter
-        SSLContext sslContext = BogusSslContextFactory
+        SSLContext sslContext = BogusSSLContextFactory
             .getInstance(false);
         SslFilter sslFilter = new SslFilter(sslContext);
-        sslFilter.setUseClientMode(true);
         connector.getFilterChain().addFirst("sslFilter", sslFilter);
 
         connector.setHandler(this);
