@@ -22,6 +22,10 @@ package org.apache.mina.example.echoserver.ssl;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 
+import java.io.BufferedReader;
+import java.io.BufferedWriter;
+import java.io.InputStreamReader;
+import java.io.OutputStreamWriter;
 import java.net.InetSocketAddress;
 import java.net.Socket;
 import java.nio.charset.StandardCharsets;
@@ -30,7 +34,6 @@ import java.util.ArrayList;
 import java.util.List;
 
 import javax.net.ssl.SSLContext;
-import javax.net.ssl.SSLSocket;
 import javax.net.ssl.TrustManager;
 import javax.net.ssl.X509TrustManager;
 
@@ -77,41 +80,46 @@ public class SslFilterTest {
     }
 
     private void testMessageSentIsCalled(boolean useSSL) throws Exception {
-        // Workaround to fix TLS issue : http://java.sun.com/javase/javaseforbusiness/docs/TLSReadme.html
-        java.lang.System.setProperty( "sun.security.ssl.allowUnsafeRenegotiation", "true" );
+        // Workaround to fix TLS issue :
+        // http://java.sun.com/javase/javaseforbusiness/docs/TLSReadme.html
+        java.lang.System.setProperty("sun.security.ssl.allowUnsafeRenegotiation", "true");
 
         SslFilter sslFilter = null;
         if (useSSL) {
-            sslFilter = new SslFilter(BogusSslContextFactory.getInstance(true));
+            sslFilter = new SslFilter(BogusSSLContextFactory.getInstance(true));
             acceptor.getFilterChain().addLast("sslFilter", sslFilter);
         }
-        acceptor.getFilterChain().addLast(
-                "codec",
+        acceptor.getFilterChain().addLast("codec",
                 new ProtocolCodecFilter(new TextLineCodecFactory(StandardCharsets.UTF_8)));
 
         EchoHandler handler = new EchoHandler();
         acceptor.setHandler(handler);
         acceptor.bind(new InetSocketAddress(0));
         port = acceptor.getLocalAddress().getPort();
-        //System.out.println("MINA server started.");
+        // System.out.println("MINA server started.");
 
         Socket socket = getClientSocket(useSSL);
-        int bytesSent = 0;
-        bytesSent += writeMessage(socket, "test-1\n");
 
+        BufferedWriter output = new BufferedWriter(new OutputStreamWriter(socket.getOutputStream()));
+        BufferedReader input = new BufferedReader(new InputStreamReader(socket.getInputStream()));
+
+        output.write("test-1\n");
+        output.flush();
+
+        assert input.readLine().equals("test-1");
+
+        /* Commented, we don't support TLS renegociation anymore
         if (useSSL) {
             // Test renegotiation
             SSLSocket ss = (SSLSocket) socket;
-            //ss.getSession().invalidate();
+            // ss.getSession().invalidate();
             ss.startHandshake();
         }
 
-        bytesSent += writeMessage(socket, "test-2\n");
+        output.write("test-2\n");
+        output.flush();
 
-        int[] response = new int[bytesSent];
-        for (int i = 0; i < response.length; i++) {
-            response[i] = socket.getInputStream().read();
-        }
+        assert input.readLine().equals("test-2");
 
         if (useSSL) {
             // Read SSL close notify.
@@ -119,17 +127,17 @@ public class SslFilterTest {
                 continue;
             }
         }
+        */
 
         socket.close();
         while (acceptor.getManagedSessions().size() != 0) {
             Thread.sleep(100);
         }
 
-        //System.out.println("handler: " + handler.sentMessages);
-        assertEquals("handler should have sent 2 messages:", 2,
-                handler.sentMessages.size());
+        // System.out.println("handler: " + handler.sentMessages);
+        assertEquals("handler should have sent 1 messages:", 1, handler.sentMessages.size());
         assertTrue(handler.sentMessages.contains("test-1"));
-        assertTrue(handler.sentMessages.contains("test-2"));
+        //assertTrue(handler.sentMessages.contains("test-2"));
     }
 
     private int writeMessage(Socket socket, String message) throws Exception {
@@ -152,20 +160,17 @@ public class SslFilterTest {
         List<String> sentMessages = new ArrayList<String>();
 
         @Override
-        public void exceptionCaught(IoSession session, Throwable cause)
-                throws Exception {
-            //cause.printStackTrace();
+        public void exceptionCaught(IoSession session, Throwable cause) throws Exception {
+            // cause.printStackTrace();
         }
 
         @Override
-        public void messageReceived(IoSession session, Object message)
-                throws Exception {
+        public void messageReceived(IoSession session, Object message) throws Exception {
             session.write(message);
         }
 
         @Override
-        public void messageSent(IoSession session, Object message)
-                throws Exception {
+        public void messageSent(IoSession session, Object message) throws Exception {
             sentMessages.add(message.toString());
 
             if (sentMessages.size() >= 2) {
@@ -177,13 +182,11 @@ public class SslFilterTest {
     TrustManager[] trustManagers = new TrustManager[] { new TrustAnyone() };
 
     private static class TrustAnyone implements X509TrustManager {
-        public void checkClientTrusted(
-                java.security.cert.X509Certificate[] x509Certificates, String s)
+        public void checkClientTrusted(java.security.cert.X509Certificate[] x509Certificates, String s)
                 throws CertificateException {
         }
 
-        public void checkServerTrusted(
-                java.security.cert.X509Certificate[] x509Certificates, String s)
+        public void checkServerTrusted(java.security.cert.X509Certificate[] x509Certificates, String s)
                 throws CertificateException {
         }
 
